Enum luminance_front::buffer::BufferError [−][src]
#[non_exhaustive]
pub enum BufferError {
CannotCreate,
Overflow {
index: usize,
buffer_len: usize,
},
TooFewValues {
provided_len: usize,
buffer_len: usize,
},
TooManyValues {
provided_len: usize,
buffer_len: usize,
},
MapFailed,
}Expand description
Buffer errors.
Please keep in mind that this enum is non exhaustive; you will not be able to exhaustively
pattern-match against it.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Cannot create buffer.
Overflow when setting a value with a specific index.
Contains the index and the size of the buffer.
Too few values were passed to fill a buffer.
Contains the number of passed value and the size of the buffer.
Show fields
Too many values were passed to fill a buffer.
Contains the number of passed value and the size of the buffer.
Show fields
Buffer mapping failed.
Implementations
Cannot create Buffer.
Overflow when setting a value with a specific index.
Too few values were passed to fill a buffer.
Too many values were passed to fill a buffer.
Buffer mapping failed.