StencilTest

Struct StencilTest 

pub struct StencilTest {
    pub comparison: Comparison,
    pub reference: u8,
    pub mask: u8,
}
The stencil test is a bit weird. It’s a Comparison as well as the « stencil mask ».

Fields

comparison: Comparison

Comparison to apply to make a fragment pass the test.

reference: u8

Reference value for the comparison.

mask: u8

The mask to apply on the fragment stencil value.

Implementations

Source

impl StencilTest

pub fn new(comparison: Comparison, reference: u8, mask: u8) -> StencilTest

Create a new StencilTest from the comparison, reference and mask values.