pub enum FaceCullingOrder {
CW,
CCW,
}Expand description
Face culling order.
The order determines how a triangle is determined to be discarded. If the triangle’s vertices
wind up in the same direction as the FaceCullingOrder, it’s assigned the front side,
otherwise, it’s the back side.
Variants