SamplerType

Trait SamplerType 

pub unsafe trait SamplerType {
    // Required method
    fn sample_type() -> Type;
}
Reify a static sample type at runtime.

That trait is used to allow sampling with different types than the actual encoding of the texture as long as the Type remains the same.

Required Methods

fn sample_type() -> Type

Underlying type of the sampler.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors