StageError

Enum StageError 

#[non_exhaustive]
pub enum StageError { CompilationFailed(StageType, String), UnsupportedType(StageType), }
Errors that shader stages can emit.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


CompilationFailed(StageType, String)

Occurs when a shader fails to compile.



UnsupportedType(StageType)

Occurs when you try to create a shader which type is not supported on the current hardware.

Implementations

Source

impl StageError

pub fn compilation_failed( ty: StageType, reason: impl Into<String>, ) -> StageError

Occurs when a shader fails to compile.

pub fn unsupported_type(ty: StageType) -> StageError

Occurs when you try to create a shader which type is not supported on the current hardware.