UniformType

Enum UniformType 

pub enum UniformType {
Show 45 variants Int, UInt, Float, Double, Bool, IVec2, IVec3, IVec4, UIVec2, UIVec3, UIVec4, Vec2, Vec3, Vec4, DVec2, DVec3, DVec4, BVec2, BVec3, BVec4, M22, M33, M44, DM22, DM33, DM44, ISampler1D, ISampler2D, ISampler3D, ISampler1DArray, ISampler2DArray, UISampler1D, UISampler2D, UISampler3D, UISampler1DArray, UISampler2DArray, Sampler1D, Sampler2D, Sampler3D, Sampler1DArray, Sampler2DArray, ICubemap, UICubemap, Cubemap, ShaderDataBinding,
}
Type of a uniform.

This is an exhaustive list of possible types of value you can send to a shader program. A UniformType is associated to any type that can be considered sent via the Uniformable trait.

Variants



Int

32-bit signed integer.



UInt

32-bit unsigned integer.



Float

32-bit floating-point number.



Double

64-bit floating-point number.



Bool

Boolean.



IVec2

2D signed integral vector.



IVec3

3D signed integral vector.



IVec4

4D signed integral vector.



UIVec2

2D unsigned integral vector.



UIVec3

3D unsigned integral vector.



UIVec4

4D unsigned integral vector.



Vec2

2D floating-point vector.



Vec3

3D floating-point vector.



Vec4

4D floating-point vector.



DVec2

2D floating-point (double) vector.



DVec3

3D floating-point (double) vector.



DVec4

4D floating-point (double) vector.



BVec2

2D boolean vector.



BVec3

3D boolean vector.



BVec4

4D boolean vector.



M22

2×2 floating-point matrix.



M33

3×3 floating-point matrix.



M44

4×4 floating-point matrix.



DM22

2×2 floating-point (double) matrix.



DM33

3×3 floating-point (double) matrix.



DM44

4×4 floating-point (double) matrix.



ISampler1D

Signed integral 1D texture sampler.



ISampler2D

Signed integral 2D texture sampler.



ISampler3D

Signed integral 3D texture sampler.



ISampler1DArray

Signed integral 1D array texture sampler.



ISampler2DArray

Signed integral 2D array texture sampler.



UISampler1D

Unsigned integral 1D texture sampler.



UISampler2D

Unsigned integral 2D texture sampler.



UISampler3D

Unsigned integral 3D texture sampler.



UISampler1DArray

Unsigned integral 1D array texture sampler.



UISampler2DArray

Unsigned integral 2D array texture sampler.



Sampler1D

Floating-point 1D texture sampler.



Sampler2D

Floating-point 2D texture sampler.



Sampler3D

Floating-point 3D texture sampler.



Sampler1DArray

Floating-point 1D array texture sampler.



Sampler2DArray

Floating-point 2D array texture sampler.



ICubemap

Signed cubemap sampler.



UICubemap

Unsigned cubemap sampler.



Cubemap

Floating-point cubemap sampler.



ShaderDataBinding

Shader data binding.