[][src]Enum luminance_front::shader::UniformWarning

#[non_exhaustive]pub enum UniformWarning {
    Inactive(String),
    TypeMismatch(StringUniformType),
}

Warnings related to uniform issues.

Variants (Non-exhaustive)

Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Inactive(String)

Inactive uniform (not in use / no participation to the final output in shaders).

TypeMismatch(StringUniformType)

Type mismatch between the static requested type (i.e. the T in Uniform<T> for instance) and the type that got reflected from the backend in the shaders.

The first String is the name of the uniform; the second one gives the type mismatch.

Implementations

impl UniformWarning[src]

pub fn inactive<N>(name: N) -> UniformWarning where
    N: Into<String>, 
[src]

Create an inactive uniform warning.

pub fn type_mismatch<N>(name: N, ty: UniformType) -> UniformWarning where
    N: Into<String>, 
[src]

Create a type mismatch.