Mode

Enum Mode 

pub enum Mode {
    Point,
    Line,
    LineStrip,
    Triangle,
    TriangleFan,
    TriangleStrip,
    Patch(usize),
}
Primitive mode.

Some modes allow for primitive restart. Primitive restart is a cool feature that allows to break the building of a primitive to start over again. For instance, when making a curve, you can imagine gluing segments next to each other. If at some point, you want to start a new curve, you have two choices:

  • Either you stop your draw call and make another one.
  • Or you just use the primitive restart feature to ask to create another line from scratch.

Primitive restart should be used as much as possible as it will decrease the number of GPU commands you have to issue.

Deprecation notice: the next version of luminance will not support setting the primitive restart index: you will then must provide the maximum value of index type.

That feature is encoded with a special vertex index. You can setup the value of the primitive restart index with TessBuilder::set_primitive_restart_index. Whenever a vertex index is set to the same value as the primitive restart index, the value is not interpreted as a vertex index but just a marker / hint to start a new primitive.

Variants



Point

A single point.

Points are left unconnected from each other and represent a point cloud. This is the typical primitive mode you want to do, for instance, particles rendering.



Line

A line, defined by two points.

Every pair of vertices are connected together to form a straight line.



LineStrip

A strip line, defined by at least two points and zero or many other ones.

The first two vertices create a line, and every new vertex flowing in the graphics pipeline (starting from the third, then) well extend the initial line, making a curve composed of several segments.

This kind of primitive mode allows the usage of primitive restart.



Triangle

A triangle, defined by three points.



TriangleFan

A triangle fan, defined by at least three points and zero or many other ones.

Such a mode is easy to picture: a cooling fan is a circular shape, with blades. Mode::TriangleFan is kind of the same. The first vertex is at the center of the fan, then the second vertex creates the first edge of the first triangle. Every time you add a new vertex, a triangle is created by taking the first (center) vertex, the very previous vertex and the current vertex. By specifying vertices around the center, you actually create a fan-like shape.

This kind of primitive mode allows the usage of primitive restart.



TriangleStrip

A triangle strip, defined by at least three points and zero or many other ones.

This mode is a bit different from Mode::TriangleFan. The first two vertices define the first edge of the first triangle. Then, for each new vertex, a new triangle is created by taking the very previous vertex and the last to very previous vertex. What it means is that every time a triangle is created, the next vertex will share the edge that was created to spawn the previous triangle.

This mode is useful to create long ribbons / strips of triangles.

This kind of primitive mode allows the usage of primitive restart.



Patch(usize)

A general purpose primitive with n vertices, for use in tessellation shaders. For example, Mode::Patch(3) represents triangle patches, so every three vertices in the buffer form a patch.

If you want to employ tessellation shaders, this is the only primitive mode you can use.