Wrap

Enum Wrap 

pub enum Wrap {
    ClampToEdge,
    Repeat,
    MirroredRepeat,
}
How to wrap texture coordinates while sampling textures?

Variants



ClampToEdge

If textures coordinates lay outside of [0;1], they will be clamped to either 0 or 1 for every components.



Repeat

Textures coordinates are repeated if they lay outside of [0;1]. Picture this as:

// given the frac function returning the fractional part of a floating number:
coord_ith = frac(coord_ith); // always between `[0;1]`


MirroredRepeat

Same as Repeat but it will alternatively repeat between [0;1] and [1;0].