pub struct Sampler {
pub wrap_r: Wrap,
pub wrap_s: Wrap,
pub wrap_t: Wrap,
pub min_filter: MinFilter,
pub mag_filter: MagFilter,
pub depth_comparison: Option<Comparison>,
}Expand description
A Sampler object gives hint on how a Texture should be sampled.
Fields
wrap_r: WrapHow should we wrap around the r sampling coordinate?
wrap_s: WrapHow should we wrap around the s sampling coordinate?
wrap_t: WrapHow should we wrap around the t sampling coordinate?
min_filter: MinFilterMinification filter.
mag_filter: MagFilterMagnification filter.
depth_comparison: Option<Comparison>For depth textures, should we perform depth comparison and if so, how?