pub enum Normalized {
Yes,
No,
}Expand description
Whether an integral vertex type should be normalized when fetched from a shader program.
The default implementation is not to normalize anything. You have to explicitly ask for normalized integers (that will, then, be accessed as floating vertex attributes).
Variants
Yes
Normalize integral values and expose them as floating-point values.
No
Do not perform any normalization and hence leave integral values as-is.