pub enum VertexInstancing {
On,
Off,
}Expand description
Should vertex instancing be used for a vertex attribute?
Enabling this is done per attribute but if you enable it for a single attribute of a struct, it should be enabled for all others (interleaved vertex instancing is not supported).
Variants