pub struct StencilOperations {
pub depth_passes_stencil_fails: StencilOp,
pub depth_fails_stencil_passes: StencilOp,
pub depth_stencil_pass: StencilOp,
}Expand description
The stencil operations are executed whenever a stencil test passes.
Fields
depth_passes_stencil_fails: StencilOpAction to take when the depth test passes but not the stencil test.
depth_fails_stencil_passes: StencilOpAction to take when the stencil test passes but not the depth test.
depth_stencil_pass: StencilOpAction to take when both the depth and stencil tests pass.
Implementations
Sourceimpl StencilOperations
impl StencilOperations
Sourcepub fn new() -> StencilOperations
pub fn new() -> StencilOperations
Create Default StencilOperations.
Sourcepub fn on_depth_passes_stencil_fails(self, op: StencilOp) -> StencilOperations
pub fn on_depth_passes_stencil_fails(self, op: StencilOp) -> StencilOperations
Set the StencilOp to do when the depth test passes but stencil test fails:
Sourcepub fn on_depth_fails_stencil_passes(self, op: StencilOp) -> StencilOperations
pub fn on_depth_fails_stencil_passes(self, op: StencilOp) -> StencilOperations
Set the StencilOp to do when the depth test fails but stencil test passes:
Sourcepub fn on_depth_stencil_pass(self, op: StencilOp) -> StencilOperations
pub fn on_depth_stencil_pass(self, op: StencilOp) -> StencilOperations
Set the StencilOp to do when both the depth test and stencil test pass: