pub struct StencilTest {
pub comparison: Comparison,
pub reference: u8,
pub mask: u8,
}Expand description
The stencil test is a bit weird. It’s a Comparison as well as the « stencil mask ».
Fields
comparison: ComparisonComparison to apply to make a fragment pass the test.
reference: u8Reference value for the comparison.
mask: u8The mask to apply on the fragment stencil value.
Implementations
Sourceimpl StencilTest
impl StencilTest
Sourcepub fn new(comparison: Comparison, reference: u8, mask: u8) -> StencilTest
pub fn new(comparison: Comparison, reference: u8, mask: u8) -> StencilTest
Create a new StencilTest from the comparison, reference and mask values.