[−][src]Trait luminance_front::pixel::SamplerType
Reify a static sample type at runtime.
That trait is used to allow sampling with different types than the actual encoding of the
texture as long as the Type remains the same.
Required methods
fn sample_type() -> Type
Underlying type of the sampler.