#[non_exhaustive]pub enum ProgramError {
CreationFailed(String),
StageError(StageError),
LinkFailed(String),
Warning(ProgramWarning),
}Expand description
Errors that a Program can generate.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CreationFailed(String)
Creating the program failed.
StageError(StageError)
A shader stage failed to compile or validate its state.
LinkFailed(String)
Program link failed. You can inspect the reason by looking at the contained String.
Warning(ProgramWarning)
A program warning.
Implementations
Sourceimpl ProgramError
impl ProgramError
Sourcepub fn creation_failed(reason: impl Into<String>) -> ProgramError
pub fn creation_failed(reason: impl Into<String>) -> ProgramError
Creating the program failed.
Sourcepub fn stage_error(e: StageError) -> ProgramError
pub fn stage_error(e: StageError) -> ProgramError
A shader stage failed to compile or validate its state.
Sourcepub fn link_failed(reason: impl Into<String>) -> ProgramError
pub fn link_failed(reason: impl Into<String>) -> ProgramError
Program link failed. You can inspect the reason by looking at the contained String.
Sourcepub fn warning(w: ProgramWarning) -> ProgramError
pub fn warning(w: ProgramWarning) -> ProgramError
A program warning.