[−][src]Enum luminance_front::shader::ProgramError
Errors that a Program can generate.
Variants (Non-exhaustive)
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
CreationFailed(String)Creating the program failed.
StageError(StageError)A shader stage failed to compile or validate its state.
LinkFailed(String)Program link failed. You can inspect the reason by looking at the contained String.
Warning(ProgramWarning)A program warning.
Implementations
impl ProgramError[src]
pub fn creation_failed(reason: impl Into<String>) -> ProgramError[src]
Creating the program failed.
pub fn stage_error(e: StageError) -> ProgramError[src]
A shader stage failed to compile or validate its state.
pub fn link_failed(reason: impl Into<String>) -> ProgramError[src]
Program link failed. You can inspect the reason by looking at the contained String.
pub fn warning(w: ProgramWarning) -> ProgramError[src]
A program warning.