[−][src]Enum luminance_front::shader::StageError
Errors that shader stages can emit.
Variants (Non-exhaustive)
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Occurs when a shader fails to compile.
UnsupportedType(StageType)Occurs when you try to create a shader which type is not supported on the current hardware.
Implementations
impl StageError[src]
pub fn compilation_failed(
ty: StageType,
reason: impl Into<String>
) -> StageError[src]
ty: StageType,
reason: impl Into<String>
) -> StageError
Occurs when a shader fails to compile.
pub fn unsupported_type(ty: StageType) -> StageError[src]
Occurs when you try to create a shader which type is not supported on the current hardware.