#[non_exhaustive]pub enum TessMapError {
CannotMap,
VertexTypeMismatch(Vec<VertexBufferDesc>, Vec<VertexBufferDesc>),
IndexTypeMismatch(TessIndexType, TessIndexType),
ForbiddenAttributelessMapping,
ForbiddenDeinterleavedMapping,
}Expand description
Error that can occur while trying to map GPU tessellations to host code.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
CannotMap
Cannot obtain a slice on the backend.
VertexTypeMismatch(Vec<VertexBufferDesc>, Vec<VertexBufferDesc>)
Vertex target type is not the same as the one stored in the buffer.
IndexTypeMismatch(TessIndexType, TessIndexType)
Index target type is not the same as the one stored in the buffer.
ForbiddenAttributelessMapping
The CPU mapping failed because you cannot map an attributeless tessellation since it doesn’t have any vertex attribute.
ForbiddenDeinterleavedMapping
The CPU mapping failed because currently, mapping deinterleaved buffers is not supported via a single slice.
Implementations
Sourceimpl TessMapError
impl TessMapError
Sourcepub fn cannot_map() -> TessMapError
pub fn cannot_map() -> TessMapError
Cannot obtain a slice on the backend.
Sourcepub fn vertex_type_mismatch(
a: Vec<VertexBufferDesc>,
b: Vec<VertexBufferDesc>,
) -> TessMapError
pub fn vertex_type_mismatch( a: Vec<VertexBufferDesc>, b: Vec<VertexBufferDesc>, ) -> TessMapError
Vertex target type is not the same as the one stored in the buffer.
Sourcepub fn index_type_mismatch(a: TessIndexType, b: TessIndexType) -> TessMapError
pub fn index_type_mismatch(a: TessIndexType, b: TessIndexType) -> TessMapError
Index target type is not the same as the one stored in the buffer.
Sourcepub fn forbidden_attributeless_mapping() -> TessMapError
pub fn forbidden_attributeless_mapping() -> TessMapError
The CPU mapping failed because you cannot map an attributeless tessellation since it doesn’t have any vertex attribute.
Sourcepub fn forbidden_deinterleaved_mapping() -> TessMapError
pub fn forbidden_deinterleaved_mapping() -> TessMapError
The CPU mapping failed because currently, mapping deinterleaved buffers is not supported via a single slice.