Enum luminance_front::tess::TessMapError [−][src]
#[non_exhaustive]
pub enum TessMapError {
BufferMapError(BufferError),
VertexTypeMismatch(Vec<VertexBufferDesc, Global>, Vec<VertexBufferDesc, Global>),
IndexTypeMismatch(TessIndexType, TessIndexType),
ForbiddenAttributelessMapping,
ForbiddenDeinterleavedMapping,
}Expand description
Error that can occur while trying to map GPU tessellations to host code.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
BufferMapError(BufferError)The CPU mapping failed due to buffer errors.
VertexTypeMismatch(Vec<VertexBufferDesc, Global>, Vec<VertexBufferDesc, Global>)Vertex target type is not the same as the one stored in the buffer.
IndexTypeMismatch(TessIndexType, TessIndexType)Index target type is not the same as the one stored in the buffer.
The CPU mapping failed because you cannot map an attributeless tessellation since it doesn’t have any vertex attribute.
The CPU mapping failed because currently, mapping deinterleaved buffers is not supported via a single slice.
Implementations
The CPU mapping failed due to buffer errors.
pub fn vertex_type_mismatch(
a: Vec<VertexBufferDesc, Global>,
b: Vec<VertexBufferDesc, Global>
) -> TessMapError
pub fn vertex_type_mismatch(
a: Vec<VertexBufferDesc, Global>,
b: Vec<VertexBufferDesc, Global>
) -> TessMapErrorVertex target type is not the same as the one stored in the buffer.
Index target type is not the same as the one stored in the buffer.
The CPU mapping failed because you cannot map an attributeless tessellation since it doesn’t have any vertex attribute.
The CPU mapping failed because currently, mapping deinterleaved buffers is not supported via a single slice.