Sampler

Struct Sampler 

pub struct Sampler {
    pub wrap_r: Wrap,
    pub wrap_s: Wrap,
    pub wrap_t: Wrap,
    pub min_filter: MinFilter,
    pub mag_filter: MagFilter,
    pub depth_comparison: Option<Comparison>,
}
A Sampler object gives hint on how a Texture should be sampled.

Fields

wrap_r: Wrap

How should we wrap around the r sampling coordinate?

wrap_s: Wrap

How should we wrap around the s sampling coordinate?

wrap_t: Wrap

How should we wrap around the t sampling coordinate?

min_filter: MinFilter

Minification filter.

mag_filter: MagFilter

Magnification filter.

depth_comparison: Option<Comparison>

For depth textures, should we perform depth comparison and if so, how?